==> wasabiD-0.2.92.tgz: package/Base/Form/Picker.jsx <==
/*
 create by wangzy
 date:2016-05-23
 desc:三级块状选择组件
 */

let React=require("react");
require("../../sass/Base/Form/picker.scss");
let alogUtil=require("../../libs/alogUtil.js");
let FetchModel=require("../../model/FetchModel.js");
let PickerModel=require("../../model/PickerModel.js");
let Picker=React.createClass({
    propTypes: {
        name:React.PropTypes.string,//用表单中的字段名称
        placeholder:React.PropTypes.string,//选择框的标题
        data: React.PropTypes.array,//数据
        url:React.PropTypes.string,//后台地址,
        params:React.PropTypes.object,//参数
        secondUrl:React.PropTypes.string,//第二层节点的后台地址,
        secondParams:React.PropTypes.object,//第二层节点的后台参数
        secondParamsKey:React.PropTypes.string,//第二层节点的后台参数中传递一级节点value值的参数名称
        thirdUrl:React.PropTypes.string,//第三层节点的后台地址，
        thirdParams:React.PropTypes.object,//第二层节点的后台参数
        thirdParamsKey:React.PropTypes.string,//第三层节点的后台参数中传递二级节点value值的参数名称
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        extraData:React.PropTypes.array,//额外的数据
        onSelect: React.PropTypes.func,//选择后的事件
    },
    getDefaultProps:function() {
        return {
            placeholder:"请选择",
            data:[],
            url:null,
            secondUrl:null,
            params:null,
            secondParams:null,
            secondParamsKey:null,
            thirdUrl:null,
            thirdParams:null,
            thirdParamsKey:null,
            valueField:"value",
            textField:"text",
            onSelect:null,
        }
    },
    getInitialState:function() {
        return {
            data:this.props.data,
            provinceActiveIndex:null,//一级激活节点下标
            cityActiveIndex:null,//二级激活节点下标
            distinctActiveIndex:null,//三级激活节点下标
        }
    },
    componentWillReceiveProps:function(nextProps) {
        if(this.props.url!=null)
        {

        }
        else {
            this.setState({
                data: nextProps.data,
            })
        }
    },
    componentDidMount:function() {
        if(this.props.url!=null) {
            var fetchmodel=new FetchModel(this.props.url,this.loadProvinceSuccess,this.props.params);
            alogUtil.fetch.post(fetchmodel);
        }
    },
    loadProvinceSuccess:function(data) {//一级节点的数据加载成功
        let provinceData=[];//一级节点数据
        var realData=data;
        //获取真实数据
        if(this.props.backSource==null) {
        }
        else {
            realData=alogUtil.getSource(data,this.props.backSource);
        }
        provinceData=   this.setPickerModel(realData);//生成标准格式model
        this.setState({
            data:provinceData
        })
    },
    setPickerModel:function(data) {//根据数据生成标准格式
        let realData = [];
        for (let index = 0; index < data.length; index++) {
            let pickerModel = new PickerModel(data[index][this.props.valueField],data[index][this.props.textField]);
            realData.push(pickerModel);
        }
        return realData;
    },
    activeProvince:function (currentIndex,currentValue) {//一级节点激活
        if(this.state.provinceActiveIndex===currentIndex)
        {
            var newData=this.state.data;
            if((newData[currentIndex].childrens instanceof  Array)&&newData[currentIndex].childrens.length>0) {
                //有子节点则不执行选中事件
                newData[currentIndex].active=!newData[currentIndex].active;
                this.setState({
                    data:newData,
                })
            }
            else {//没有则立即执行选中事件
                if (this.props.onSelect != null) {
                    this.props.onSelect(newData[currentIndex].value, newData[currentIndex].text, this.props.name);
                }
            }
        }
        else {
            if(this.props.secondUrl!=null&&this.state.data[currentIndex].childrens==null) {//存在二级节点url并且没有查询过

                let url=this.props.secondUrl;
                let params=this.props.secondParams;
                if(typeof  params =="object")
                {//判断是否为对象
                        params[this.props.secondParamsKey]=currentValue;
                }
                else
                {
                    params={};
                    if(this.props.secondParamsKey!=null)
                    {
                        params[this.props.secondParamsKey]=currentValue;
                    }

                }
                var fetchmodel=new FetchModel(url,this.loadCitySuccess.bind(this,currentIndex),params)
                alogUtil.fetch.post(fetchmodel);
            }
            else {
                var newData=this.state.data;
                for(let index=0;index<newData.length;index++)
                {
                    newData[index].active=false;
                }
                newData[currentIndex].active=true;
                this.setState({
                    data:newData,
                    provinceActiveIndex:currentIndex,
                })
                if((newData[currentIndex].childrens instanceof  Array)&&newData[currentIndex].childrens.length>0) {
                    //有子节点则不执行选中事件
                }
                else {//没有则立即执行选中事件
                    if (this.props.onSelect != null) {
                        this.props.onSelect(newData[currentIndex].value, newData[currentIndex].text, this.props.name);
                    }
                }
            }
        }

    },
    loadCitySuccess:function(currentIndex,data) {//二级节点的数据加载成功
        let cityData=[];//当前一级节点的二级节点数据
        var realData=data;
        //获取真实数据
        if(this.props.backSource==null) {
        }
        else {
            realData=alogUtil.getSource(data,this.props.backSource);
        }
        cityData=this.setPickerModel(realData);//生成二级节点数据模型
        var newData=this.state.data;
        for(var index=0;index<newData.length;index++)
        {
            newData[index].active=false;
        }
        newData[currentIndex].active=true;
        newData[currentIndex].childrens=cityData;//将查询的二级节点赋值给一级激活节点
        this.setState({
            data:newData,
            provinceActiveIndex:currentIndex,
        })
    },
    activeCity:function(currentIndex,currentValue) {//二级节点激活
        if(this.state.cityActiveIndex===currentIndex){
            var newData=this.state.data;
            if((newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens instanceof  Array)&&newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens.length>0) {
                //有子节点(三级节点)则不执行选中事件
                newData[this.state.provinceActiveIndex].childrens[currentIndex].active=!newData[this.state.provinceActiveIndex].childrens[currentIndex].active;
                this.setState({
                    data:newData,
                })
            }
            else {//没有则立即执行选中事件
                if (this.props.onSelect != null) {
                    let selectValue=newData[this.state.provinceActiveIndex].value+","+newData[this.state.provinceActiveIndex].childrens[currentIndex].value;
                    let selectText=newData[this.state.provinceActiveIndex].text+","+newData[this.state.provinceActiveIndex].childrens[currentIndex].text;
                    this.props.onSelect(selectValue, selectText, this.props.name);
                }
            }

        }
        else
        {
            if(this.props.thirdUrl!=null&&(this.state.data[this.state.provinceActiveIndex].childrens[currentIndex].childrens==null)) {//存在三级节点url并且没有查询过
                let url=this.props.thirdUrl;
                let params=this.props.thirdParams;
                if(typeof  params =="object")
                {//判断是否为对象
                    params[this.props.thirdParamsKey]=currentValue;
                }
                else
                {
                    params={};
                    if(this.props.thirdParamsKey!=null)
                    {
                        params[this.props.thirdParamsKey]=currentValue;
                    }
                }
                var fetchmodel=new FetchModel(url,this.loadDistinctSuccess.bind(this,currentIndex),params);
                alogUtil.fetch.post(fetchmodel);
            }
            else {
                var newData=this.state.data;
                for(let index=0;index<newData[this.state.provinceActiveIndex].childrens.length;index++)
                {
                    newData[this.state.provinceActiveIndex].childrens[index].active=false;
                }
                newData[this.state.provinceActiveIndex].childrens[currentIndex].active=true;
                this.setState({
                    data:newData,
                    cityActiveIndex:currentIndex,
                });
                if((newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens instanceof  Array)&&newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens.length>0) {
                    //有子节点(三级节点)则不执行选中事件
                }
                else {//没有则立即执行选中事件
                    if (this.props.onSelect != null) {
                        let selectValue=newData[this.state.provinceActiveIndex].value+","+newData[this.state.provinceActiveIndex].childrens[currentIndex].value;
                        let selectText=newData[this.state.provinceActiveIndex].text+","+newData[this.state.provinceActiveIndex].childrens[currentIndex].text;
                        this.props.onSelect(selectValue, selectText, this.props.name);
                    }
                }
            }
        }

    },
    loadDistinctSuccess:function(currentIndex,data){//三级节点查询成功
        let distinctData=[];//当前二级节点的二级节点数据
        var realData=data;
        //获取真实数据
        if(this.props.backSource==null) {
        }
        else {
            realData=alogUtil.getSource(data,this.props.backSource);
        }
        distinctData=this.setPickerModel(realData);//生成二级节点数据模型
        var newData=this.state.data;
        for(var index=0;index<newData[this.state.provinceActiveIndex].childrens.length;index++)
        {
            newData[this.state.provinceActiveIndex].childrens[index].active=false;
        }
        newData[this.state.provinceActiveIndex].childrens[currentIndex].active=true;
        newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens=distinctData;//将查询的三级节点赋值给二级激活节点
        this.setState({
            data:newData,
            cityActiveIndex:currentIndex,
        })
    },
    activeDistinct:function(currentIndex) {//三级节点激活
        var newData=this.state.data;
        for(let index=0;index< newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens.length;index++)
        {
            newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens[index].active=false;
        }
        newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens[currentIndex].active=true;
        this.setState({
            data:newData,
            distinctActiveIndex:currentIndex,
        })
        if (this.props.onSelect != null) {
            let selectValue=newData[this.state.provinceActiveIndex].value +","
                +newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].value+","
                +newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens[currentIndex].value;
            let selectText=newData[this.state.provinceActiveIndex].text +","
                +newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].text+","
                +newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens[currentIndex].text;
            this.props.onSelect(selectValue, selectText, this.props.name);
        }
    },
    renderProvince:function () {//一级节点渲染
        var provinceComponents=[];
        if(this.state.data instanceof  Array)
        {
            this.state.data.map((child,index)=>
            {
                var left=(index%5)*-65;

                provinceComponents.push (<li key={"province"+index} className={"picker-container  "+(child.active?"active":"")}>
                        <ul className="picker-container-wrap" style={{display:(child.active?"block":"none"),left:left}}>
                            {
                                this.renderCity(child.childrens)
                            }
                        </ul>
                        <div className={"picker-container-name "+(child.active?"active":"")} onClick={this.activeProvince.bind(this,index,child.value)} title={child.text}>{child.text}</div>
                    </li>
                );
            });
            return provinceComponents;
        }
        else
        {
            return null;
        }


    },
    renderCity:function(cityData) {//二级节点渲染
        var cityComponents=[];
        if(cityData instanceof  Array)
        {
            cityData.map((child,index)=>{
                var left=(index%4)*-80;
                if(index%4==0)
                {
                    left=-14;
                }

                cityComponents.push (
                    <li key={"city"+index} className={"picker-container  "+(child.active?"active":"")}>
                        <ul className="picker-container-wrap" style={{display:(child.active?"block":"none"),left:left}}>
                            {
                                this.renderDistinct(child.childrens)
                            }
                        </ul>
                        <div className={"picker-container-name "+(child.active?"active":"")} onClick={this.activeCity.bind(this,index,child.value)} title={child.text}>{child.text}</div>
                    </li>
                )
            });
            return cityComponents;
        }else
        {
            return null;
        }

    },
    renderDistinct:function(distinctData) {//三级节点渲染
        var distinctComponents=[];
        if(distinctData instanceof  Array)
        {
            distinctData.map((child,index)=>{
                distinctComponents.push (
                    <li key={"distinct"+index} className={"pickeritem "+(this.state.distinctActiveIndex===index?"active":"")}  onClick={this.activeDistinct.bind(this,index,child.value)} title={child.text}>{child.text}</li>
                )
            });
            return distinctComponents;
        }else
        {
            return null;
            return null;
        }

    },
    render:function() {
        var control=this.renderProvince();
        return (
            <div className="picker">

                <ul className="wrap" >
                    <p>{this.props.placeholder}</p>
                    {
                        this.renderProvince()
                    }
                </ul>

            </div>
        )
    }
});
module .exports=Picker;

==> wasabiD-0.2.983.tgz: package/Base/Form/Picker.jsx <==
/*
 create by wangzy
 date:2016-05-23
 desc:三级块状选择组件
 */

let React=require("react");
require("../../sass/Base/Form/picker.scss");
let unit=require("../../libs/unit.js");
let FetchModel=require("../../model/FetchModel.js");
let PickerModel=require("../../model/PickerModel.js");
let Picker=React.createClass({
    propTypes: {
        name:React.PropTypes.string,//用表单中的字段名称
        placeholder:React.PropTypes.string,//选择框的标题
        data: React.PropTypes.array,//数据
        url:React.PropTypes.string,//后台地址,
        params:React.PropTypes.object,//参数
        secondUrl:React.PropTypes.string,//第二层节点的后台地址,
        secondParams:React.PropTypes.object,//第二层节点的后台参数
        secondParamsKey:React.PropTypes.string,//第二层节点的后台参数中传递一级节点value值的参数名称
        thirdUrl:React.PropTypes.string,//第三层节点的后台地址，
        thirdParams:React.PropTypes.object,//第二层节点的后台参数
        thirdParamsKey:React.PropTypes.string,//第三层节点的后台参数中传递二级节点value值的参数名称
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        extraData:React.PropTypes.array,//额外的数据
        onSelect: React.PropTypes.func,//选择后的事件
    },
    getDefaultProps:function() {
        return {
            placeholder:"请选择",
            data:[],
            url:null,
            secondUrl:null,
            params:null,
            secondParams:null,
            secondParamsKey:null,
            thirdUrl:null,
            thirdParams:null,
            thirdParamsKey:null,
            valueField:"value",
            textField:"text",
            onSelect:null,
        }
    },
    getInitialState:function() {
        return {
            data:this.props.data,
            provinceActiveIndex:null,//一级激活节点下标
            cityActiveIndex:null,//二级激活节点下标
            distinctActiveIndex:null,//三级激活节点下标
        }
    },
    componentWillReceiveProps:function(nextProps) {
        if(this.props.url!=null)
        {

        }
        else {
            this.setState({
                data: nextProps.data,
            })
        }
    },
    componentDidMount:function() {
        if(this.props.url!=null) {
            var fetchmodel=new FetchModel(this.props.url,this.loadProvinceSuccess,this.props.params);
            unit.fetch.post(fetchmodel);
        }
    },
    loadProvinceSuccess:function(data) {//一级节点的数据加载成功
        let provinceData=[];//一级节点数据
        var realData=data;
        //获取真实数据
        if(this.props.backSource==null) {
        }
        else {
            realData=unit.getSource(data,this.props.backSource);
        }
        provinceData=   this.setPickerModel(realData);//生成标准格式model
        this.setState({
            data:provinceData
        })
    },
    setPickerModel:function(data) {//根据数据生成标准格式
        let realData = [];
        for (let index = 0; index < data.length; index++) {
            let pickerModel = new PickerModel(data[index][this.props.valueField],data[index][this.props.textField]);
            realData.push(pickerModel);
        }
        return realData;
    },
    activeProvince:function (currentIndex,currentValue) {//一级节点激活
        if(this.state.provinceActiveIndex===currentIndex)
        {
            var newData=this.state.data;
            if((newData[currentIndex].childrens instanceof  Array)&&newData[currentIndex].childrens.length>0) {
                //有子节点则不执行选中事件
                newData[currentIndex].active=!newData[currentIndex].active;
                this.setState({
                    data:newData,
                })
            }
            else {//没有则立即执行选中事件
                if (this.props.onSelect != null) {
                    this.props.onSelect(newData[currentIndex].value, newData[currentIndex].text, this.props.name);
                }
            }
        }
        else {
            if(this.props.secondUrl!=null&&this.state.data[currentIndex].childrens==null) {//存在二级节点url并且没有查询过

                let url=this.props.secondUrl;
                let params=this.props.secondParams;
                if(typeof  params =="object")
                {//判断是否为对象
                        params[this.props.secondParamsKey]=currentValue;
                }
                else
                {
                    params={};
                    if(this.props.secondParamsKey!=null)
                    {
                        params[this.props.secondParamsKey]=currentValue;
                    }

                }
                var fetchmodel=new FetchModel(url,this.loadCitySuccess.bind(this,currentIndex),params)
                unit.fetch.post(fetchmodel);
            }
            else {
                var newData=this.state.data;
                for(let index=0;index<newData.length;index++)
                {
                    newData[index].active=false;
                }
                newData[currentIndex].active=true;
                this.setState({
                    data:newData,
                    provinceActiveIndex:currentIndex,
                })
                if((newData[currentIndex].childrens instanceof  Array)&&newData[currentIndex].childrens.length>0) {
                    //有子节点则不执行选中事件
                }
                else {//没有则立即执行选中事件
                    if (this.props.onSelect != null) {
                        this.props.onSelect(newData[currentIndex].value, newData[currentIndex].text, this.props.name);
                    }
                }
            }
        }

    },
    loadCitySuccess:function(currentIndex,data) {//二级节点的数据加载成功
        let cityData=[];//当前一级节点的二级节点数据
        var realData=data;
        //获取真实数据
        if(this.props.backSource==null) {
        }
        else {
            realData=unit.getSource(data,this.props.backSource);
        }
        cityData=this.setPickerModel(realData);//生成二级节点数据模型
        var newData=this.state.data;
        for(var index=0;index<newData.length;index++)
        {
            newData[index].active=false;
        }
        newData[currentIndex].active=true;
        newData[currentIndex].childrens=cityData;//将查询的二级节点赋值给一级激活节点
        this.setState({
            data:newData,
            provinceActiveIndex:currentIndex,
        })
    },
    activeCity:function(currentIndex,currentValue) {//二级节点激活
        if(this.state.cityActiveIndex===currentIndex){
            var newData=this.state.data;
            if((newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens instanceof  Array)&&newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens.length>0) {
                //有子节点(三级节点)则不执行选中事件
                newData[this.state.provinceActiveIndex].childrens[currentIndex].active=!newData[this.state.provinceActiveIndex].childrens[currentIndex].active;
                this.setState({
                    data:newData,
                })
            }
            else {//没有则立即执行选中事件
                if (this.props.onSelect != null) {
                    let selectValue=newData[this.state.provinceActiveIndex].value+","+newData[this.state.provinceActiveIndex].childrens[currentIndex].value;
                    let selectText=newData[this.state.provinceActiveIndex].text+","+newData[this.state.provinceActiveIndex].childrens[currentIndex].text;
                    this.props.onSelect(selectValue, selectText, this.props.name);
                }
            }

        }
        else
        {
            if(this.props.thirdUrl!=null&&(this.state.data[this.state.provinceActiveIndex].childrens[currentIndex].childrens==null)) {//存在三级节点url并且没有查询过
                let url=this.props.thirdUrl;
                let params=this.props.thirdParams;
                if(typeof  params =="object")
                {//判断是否为对象
                    params[this.props.thirdParamsKey]=currentValue;
                }
                else
                {
                    params={};
                    if(this.props.thirdParamsKey!=null)
                    {
                        params[this.props.thirdParamsKey]=currentValue;
                    }
                }
                var fetchmodel=new FetchModel(url,this.loadDistinctSuccess.bind(this,currentIndex),params);
                unit.fetch.post(fetchmodel);
            }
            else {
                var newData=this.state.data;
                for(let index=0;index<newData[this.state.provinceActiveIndex].childrens.length;index++)
                {
                    newData[this.state.provinceActiveIndex].childrens[index].active=false;
                }
                newData[this.state.provinceActiveIndex].childrens[currentIndex].active=true;
                this.setState({
                    data:newData,
                    cityActiveIndex:currentIndex,
                });
                if((newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens instanceof  Array)&&newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens.length>0) {
                    //有子节点(三级节点)则不执行选中事件
                }
                else {//没有则立即执行选中事件
                    if (this.props.onSelect != null) {
                        let selectValue=newData[this.state.provinceActiveIndex].value+","+newData[this.state.provinceActiveIndex].childrens[currentIndex].value;
                        let selectText=newData[this.state.provinceActiveIndex].text+","+newData[this.state.provinceActiveIndex].childrens[currentIndex].text;
                        this.props.onSelect(selectValue, selectText, this.props.name);
                    }
                }
            }
        }

    },
    loadDistinctSuccess:function(currentIndex,data){//三级节点查询成功
        let distinctData=[];//当前二级节点的二级节点数据
        var realData=data;
        //获取真实数据
        if(this.props.backSource==null) {
        }
        else {
            realData=unit.getSource(data,this.props.backSource);
        }
        distinctData=this.setPickerModel(realData);//生成二级节点数据模型
        var newData=this.state.data;
        for(var index=0;index<newData[this.state.provinceActiveIndex].childrens.length;index++)
        {
            newData[this.state.provinceActiveIndex].childrens[index].active=false;
        }
        newData[this.state.provinceActiveIndex].childrens[currentIndex].active=true;
        newData[this.state.provinceActiveIndex].childrens[currentIndex].childrens=distinctData;//将查询的三级节点赋值给二级激活节点
        this.setState({
            data:newData,
            cityActiveIndex:currentIndex,
        })
    },
    activeDistinct:function(currentIndex) {//三级节点激活
        var newData=this.state.data;
        for(let index=0;index< newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens.length;index++)
        {
            newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens[index].active=false;
        }
        newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens[currentIndex].active=true;
        this.setState({
            data:newData,
            distinctActiveIndex:currentIndex,
        })
        if (this.props.onSelect != null) {
            let selectValue=newData[this.state.provinceActiveIndex].value +","
                +newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].value+","
                +newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens[currentIndex].value;
            let selectText=newData[this.state.provinceActiveIndex].text +","
                +newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].text+","
                +newData[this.state.provinceActiveIndex].childrens[this.state.cityActiveIndex].childrens[currentIndex].text;
            this.props.onSelect(selectValue, selectText, this.props.name);
        }
    },
    renderProvince:function () {//一级节点渲染
        var provinceComponents=[];
        if(this.state.data instanceof  Array)
        {
            this.state.data.map((child,index)=>
            {
                var left=(index%5)*-65;

                provinceComponents.push (<li key={"province"+index} className={"picker-container  "+(child.active?"active":"")}>
                        <ul className="picker-container-wrap" style={{display:(child.active?"block":"none"),left:left}}>
                            {
                                this.renderCity(child.childrens)
                            }
                        </ul>
                        <div className={"picker-container-name "+(child.active?"active":"")} onClick={this.activeProvince.bind(this,index,child.value)} title={child.text}>{child.text}</div>
                    </li>
                );
            });
            return provinceComponents;
        }
        else
        {
            return null;
        }


    },
    renderCity:function(cityData) {//二级节点渲染
        var cityComponents=[];
        if(cityData instanceof  Array)
        {
            cityData.map((child,index)=>{
                var left=(index%4)*-80;
                if(index%4==0)
                {
                    left=-14;
                }

                cityComponents.push (
                    <li key={"city"+index} className={"picker-container  "+(child.active?"active":"")}>
                        <ul className="picker-container-wrap" style={{display:(child.active?"block":"none"),left:left}}>
                            {
                                this.renderDistinct(child.childrens)
                            }
                        </ul>
                        <div className={"picker-container-name "+(child.active?"active":"")} onClick={this.activeCity.bind(this,index,child.value)} title={child.text}>{child.text}</div>
                    </li>
                )
            });
            return cityComponents;
        }else
        {
            return null;
        }

    },
    renderDistinct:function(distinctData) {//三级节点渲染
        var distinctComponents=[];
        if(distinctData instanceof  Array)
        {
            distinctData.map((child,index)=>{
                distinctComponents.push (
                    <li key={"distinct"+index} className={"pickeritem "+(this.state.distinctActiveIndex===index?"active":"")}  onClick={this.activeDistinct.bind(this,index,child.value)} title={child.text}>{child.text}</li>
                )
            });
            return distinctComponents;
        }else
        {
            return null;
            return null;
        }

    },
    render:function() {
        var control=this.renderProvince();
        return (
            <div className="picker">

                <ul className="wrap" >
                    <p>{this.props.placeholder}</p>
                    {
                        this.renderProvince()
                    }
                </ul>

            </div>
        )
    }
});
module .exports=Picker;
